@@ -7,7 +7,7 @@ logger = logging.getLogger(__file__)
 
 class LocalEmailBackend(EmailBackend):
     def send_email(self, template: EmailTemplate, to: str, subject: str):
-        logger.debug(f"=== Email sending ===")
-        logger.debug(f"Template: {template}")
-        logger.debug(f"To: {to}")
-        logger.debug(f"Subject: {subject}")
+        logger.info(f"=== Email sending ===")
+        logger.info(f"Template: {template}")
+        logger.info(f"To: {to}")
+        logger.info(f"Subject: {subject}")
